@@ -25,7 +25,7 @@
 ###
 
 cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, main, xlab, ylab, 
-                        datacol, fillrect, fitlty, fitcol, addlegend = TRUE, legendtext, xlegend = "bottomright", 
+                        datacol, fillrect, fitlty, fitcol, fitlwd, addlegend = TRUE, legendtext, xlegend = "bottomright", 
                         ylegend = NULL, lines01 = FALSE,Turnbull.confint = FALSE, 
                         NPMLE.method = "Wang", 
                         add = FALSE, plotstyle = "graphics", ...)
@@ -50,8 +50,8 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
             of Turnbull.intervals. It was here fixed as Turnbull.middlepoints, equivalent to former Turnbull.")
     NPMLE.method <- "Turnbull.middlepoints"
   }
-
-    if ((Turnbull.confint == TRUE) & ((NPMLE.method == "Wang") | (NPMLE.method == "Turnbull.intervals")))
+  
+  if ((Turnbull.confint == TRUE) & ((NPMLE.method == "Wang") | (NPMLE.method == "Turnbull.intervals")))
   {
     warning("When Turnbull.confint is TRUE NPMLE.method is forced to Turnbull.middlepoints." )
     NPMLE.method <- "Turnbull.middlepoints"
@@ -75,8 +75,10 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
   if (missing(fillrect)) fillrect <- "lightgrey"
   if (missing(fitcol)) fitcol <- 2:(nft+1)
   if (missing(fitlty)) fitlty <- 1:nft
+  if (missing(fitlwd)) fitlwd <- 1
   fitcol <- rep(fitcol, length.out=nft)
   fitlty <- rep(fitlty, length.out=nft)
+  fitlwd <- rep(fitlwd, length.out=nft)
   
   if (missing(xlab))
     xlab <- ifelse(xlogscale, "censored data in log scale", "censored data")
@@ -98,9 +100,10 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
   
   
   # calculations for Wang method, for both graphics and ggplot displays
-  if ((NPMLE.method == "Wang") | (NPMLE.method == "Turnbull.intervals")) {
+  if ((NPMLE.method == "Wang") | (NPMLE.method == "Turnbull.intervals"))
+  {
     f <- npmle(censdata, method = NPMLE.method)
-  
+    
     bounds <- c(f$right, f$left)
     finitebounds <- bounds[is.finite(bounds)]
     upper <- max(finitebounds)
@@ -179,11 +182,10 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
       legendtext <- paste(legendtext, 1:nft, sep="-")
   }
   
-  
-  if(plotstyle == "graphics") {
+  if(plotstyle == "graphics") 
+  {
     ######## plot if plotstyle=='graphics' ########
     
-    
     if (NPMLE.method == "Turnbull.middlepoints")
       # Turnbull plot
     {
@@ -192,8 +194,7 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
         xmin <- min(c(censdata$left, censdata$right), na.rm=TRUE)
         xmax <- max(c(censdata$left, censdata$right), na.rm=TRUE)
         xlim <- c(xmin, xmax)
-      }
-      else
+      }else
       {
         xmin <- xlim[1]
         xmax <- xlim[2]
@@ -227,8 +228,7 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
                   log=logxy, col=datacol, conf.int = FALSE, xlim = xlim, ...)
           
         }
-      }
-      else
+      }else
       {
         if (Turnbull.confint)
         {
@@ -268,7 +268,8 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
       # rgbdatacol <- col2rgb(datacol)
       # lightdatacol <- rgb(rgbdatacol[1], rgbdatacol[2], rgbdatacol[3], maxColorValue = 255, 
       #                     alpha = 10)
-      for(i in 1:k) {
+      for(i in 1:k) 
+      {
         rect(xleft = Qi.left4plot, ybottom = Pi.low, xright = Qi.right4plot, ytop = Pi.up,
              border = datacol, col = fillrect)
       }
@@ -292,7 +293,7 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
         sfin <- seq(xmin, xmax, by=(xmax-xmin)/100)
       }
       theopfin <- do.call(pdistname, c(list(sfin), as.list(para)))
-      lines(sfin, theopfin, lty=fitlty[i], col=fitcol[i], ...)
+      lines(sfin, theopfin, lty=fitlty[i], col=fitcol[i], lwd=fitlwd[i], ...)
     }
     
     s <- sapply(1:nft, plot.fti, ...)
@@ -303,16 +304,15 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
     
     if (addlegend)
     {
-      legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, lty=fitlty, col=fitcol, ...)
+      legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, lty=fitlty, col=fitcol, lwd=fitlwd, ...)
     }
-    
     invisible()
     
-    
-  } else if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  } else if (!requireNamespace("ggplot2", quietly = TRUE)) 
+  {
     stop("ggplot2 needed for this function to work with plotstyle = 'ggplot'. Please install it", call. = FALSE)
-    
-  } else {
+  } else 
+  {
     ######## plot if plotstyle=='ggplot' ########
     if ((NPMLE.method == "Wang") | (NPMLE.method == "Turnbull.intervals")) {
       
@@ -325,14 +325,16 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
         xlegend <- "right"
       
       # the line at right of the rectangles
-      dsegmright <- cbind(dright, Fright)[2:9,]
-      dsegmright <- cbind(dsegmright[-8, ], dsegmright[-1,])
+      dsegmright <- cbind(dright, Fright)
+      dsegmright <- cbind(dsegmright[seq(1, nrow(dsegmright), by = 2), ], 
+                          dsegmright[seq(2, nrow(dsegmright), by = 2), ])
       dsegmright <- as.data.frame(dsegmright)
       colnames(dsegmright) <- c("x1", "y1", "x2", "y2")
       
       # the line at left of the rectangles
-      dsegmleft <- cbind(dleft, Fleft)[2:9,]
-      dsegmleft <- cbind(dsegmleft[-8, ], dsegmleft[-1,])
+      dsegmleft <- cbind(dleft, Fleft)
+      dsegmleft <- cbind(dsegmleft[seq(1, nrow(dsegmleft), by = 2), ],
+                         dsegmleft[seq(2, nrow(dsegmleft), by = 2), ])
       dsegmleft <- as.data.frame(dsegmleft)
       colnames(dsegmleft) <- c("x1", "y1", "x2", "y2")
       
@@ -363,16 +365,18 @@ cdfcompcens <- function(ft, xlim, ylim, xlogscale = FALSE, ylogscale = FALSE, ma
         ggplot2::ggtitle(main) + ggplot2::xlab(xlab) + ggplot2::ylab(ylab) +
         {if(lines01) ggplot2::geom_hline(ggplot2::aes(yintercept=0), color="grey", linetype="dashed")} +
         {if(lines01) ggplot2::geom_hline(ggplot2::aes(yintercept=1), color="grey", linetype="dashed")} +
-        ggplot2::geom_rect(data=drect, mapping=ggplot2::aes_(xmin=quote(x1), xmax=quote(x2), ymin=quote(y1), ymax=quote(y2)), colour = datacol, fill = fillrect, alpha=0.5) +
-        ggplot2::geom_segment(data=dsegmright, mapping=ggplot2::aes_(x=quote(x1), y=quote(y1), xend=quote(x2), yend=quote(y2)), colour = datacol) +
-        ggplot2::geom_segment(data=dsegmleft, mapping=ggplot2::aes_(x=quote(x1), y=quote(y1), xend=quote(x2), yend=quote(y2)), colour = datacol) +
-        ggplot2::geom_line(data=dline, ggplot2::aes_(quote(x), quote(y), group = quote(ind), colour = quote(ind), linetype = quote(ind))) +
+        ggplot2::geom_rect(data=drect, mapping=ggplot2::aes(xmin=.data$x1, xmax=.data$x2, ymin=.data$y1, ymax=.data$y2), colour = datacol, fill = fillrect, alpha=0.5) +
+        ggplot2::geom_segment(data=dsegmright, mapping=ggplot2::aes(x=.data$x1, y=.data$y1, xend=.data$x2, yend=.data$y2), colour = datacol) +
+        ggplot2::geom_segment(data=dsegmleft, mapping=ggplot2::aes(x=.data$x1, y=.data$y1, xend=.data$x2, yend=.data$y2), colour = datacol) +
+        ggplot2::geom_line(data=dline, ggplot2::aes(.data$x, .data$y, group = .data$ind, colour = .data$ind, linetype = .data$ind, size = .data$ind)) +
         ggplot2::theme_bw() +
         {if(addlegend) ggplot2::theme(legend.position = c(xlegend, ylegend), plot.title = ggplot2::element_text(hjust = 0.5)) else ggplot2::theme(legend.position = "none", plot.title = ggplot2::element_text(hjust = 0.5))} +
         ggplot2::scale_color_manual(values = fitcol, labels = legendtext) +
         ggplot2::scale_linetype_manual(values = fitlty, labels = legendtext) +
+        ggplot2::scale_size_manual(values = fitlwd, labels = legendtext) +
         ggplot2::guides(colour = ggplot2::guide_legend(title = NULL)) +
         ggplot2::guides(linetype = ggplot2::guide_legend(title = NULL)) +
+        ggplot2::guides(size = ggplot2::guide_legend(title = NULL)) +
         {if(xlogscale) ggplot2::scale_x_continuous(trans='log10')} +
         {if(ylogscale) ggplot2::scale_y_continuous(trans='log10')}
       
