@@ -27,7 +27,7 @@
 
 
 denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab, 
-                     datacol, fitlty, fitcol, addlegend = TRUE, legendtext, 
+                     datacol, fitlty, fitcol, fitlwd, addlegend = TRUE, legendtext, 
                      xlegend = "topright", ylegend = NULL, demp = FALSE, 
                      dempcol = "black", plotstyle = "graphics", 
                      discrete, fitnbpts = 101, fittype="l", ...)
@@ -61,8 +61,10 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
   if (missing(datacol)) datacol <- NULL    
   if (missing(fitcol)) fitcol <- 2:(nft+1)
   if (missing(fitlty)) fitlty <- 1:nft
+  if (missing(fitlwd)) fitlwd <- 1
   fitcol <- rep(fitcol, length.out=nft)
   fitlty <- rep(fitlty, length.out=nft)
+  fitlwd <- rep(fitlwd, length.out=nft)
   fittype <- match.arg(fittype[1], c("p", "l", "o"))
   
   if (missing(xlab))
@@ -118,17 +120,17 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
       scalefactor <- 1
     } else
     {
-      if (length(unique(diff(reshist$breaks))) > 1) # wrong histogram and not possibleto compute a scalefactor
+      if (length(unique(diff(reshist$breaks))) > 1) # wrong histogram and not possible to compute a scale factor
         stop("You should not use probability = FALSE with non-equidistant breaks for the histogram !") else
-      scalefactor <- n * diff(reshist$breaks)[1]
+          scalefactor <- n * diff(reshist$breaks)[1]
     }
-#    previous writing that gave incorrect output in case of probability = 1 and non-equidistant breaks
-#    scalefactor <- ifelse(probability, 1, n * diff(reshist$breaks))
+    #    previous writing that gave incorrect output in case of probability = 1 and non-equidistant breaks
+    #    scalefactor <- ifelse(probability, 1, n * diff(reshist$breaks))
   } else
   {
     scalefactor <- ifelse(probability, 1, n)
   }
-#  binwidth <- min(diff(reshist$breaks))
+  #  binwidth <- min(diff(reshist$breaks))
   
   # computation of each fitted distribution
   comput.fti <- function(i)
@@ -188,12 +190,13 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
   {
     legendtext <- c(legendtext, "emp.")
     fitlty <- c(fitlty, 1)
+    fitlwd <- c(fitlwd, 1)
     fitcol <- c(fitcol, dempcol)
   }
   
-  if(plotstyle == "graphics") {
+  if(plotstyle == "graphics") 
+  {
     ######## plot if plotstyle=='graphics' ########
-    
     if(!discrete)
     {
       #main plotting
@@ -201,28 +204,28 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
       
       #plot fitted densities (line)
       for(i in 1:nft)
-          lines(sfin, fitteddens[,i], lty=fitlty[i], col=fitcol[i], ...)
- 
+        lines(sfin, fitteddens[,i], lty=fitlty[i], col=fitcol[i], lwd=fitlwd[i], ...)
+      
       #plot empirical density
       if(demp)
         lines(density(mydata)$x, density(mydata)$y * scalefactor, col=dempcol)
       
       if (addlegend)
-        legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, lty=fitlty, col=fitcol, ...)
+        legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, lty=fitlty, col=fitcol, lwd=fitlwd, ...)
     }else # so if discrete
     {
       #main plotting
-      # plotting of an empty histogramm
+      # plotting of an empty histogram
       reshist <- hist(mydata, main = main, xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, border = "white",
                       probability = probability, ...)
-       
+      
       eps <- diff(range(sfin))/200
       if(fittype %in% c("l", "o"))
       {
         #plot fitted mass probability functions (line)
         for(i in 1:nft)
-          lines(sfin+(i)*eps, fitteddens[,i], lty=fitlty[i], col=fitcol[i], type="h", ...)
-        #plot empirical mass probabilty function
+          lines(sfin+(i)*eps, fitteddens[,i], lty=fitlty[i], col=fitcol[i], lwd=fitlwd[i], type="h", ...)
+        #plot empirical mass probability function
         if(demp)
         {
           empval <- sort(unique(mydata))
@@ -245,19 +248,18 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
       }
       
       if (addlegend && fittype %in% c("l", "o"))
-        legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, lty=fitlty, col=fitcol, ...)
+        legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, lty=fitlty, col=fitcol, lwd=fitlwd, ...)
       if (addlegend && fittype == "p")
         legend(x=xlegend, y=ylegend, bty="n", legend=legendtext, pch=1, col=fitcol, ...)
     }
-    invisible()
+    return(invisible(list(hist = reshist, densities = fitteddens)))
     
-    
-  } else if (!requireNamespace("ggplot2", quietly = TRUE)) {
+  } else if (!requireNamespace("ggplot2", quietly = TRUE)) 
+  {
     stop("ggplot2 needed for this function to work with plotstyle = 'ggplot'. Please install it", call. = FALSE)
-    
-  } else {
+  } else 
+  {
     ######## plot if plotstyle=='ggplot' ########
-    
     # recode the legend position according to available positions in ggplot2
     if(xlegend %in% c("topleft", "bottomleft"))
       xlegend <- "left"
@@ -281,21 +283,23 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
       
       histdata <- data.frame(values = mydata, ind = "hist", sfin = mydata) # the added data must have the same column names as the main data to be compatible with ggplot
       
-        ggdenscomp <-
-        ggplot2::ggplot(fitteddens, ggplot2::aes_(quote(sfin), quote(values), group = quote(ind), colour = quote(ind))) +
+      ggdenscomp <-
+        ggplot2::ggplot(fitteddens, ggplot2::aes(.data$sfin, .data$values, group = .data$ind, colour = .data$ind)) +
         ggplot2::xlab(xlab) +
         ggplot2::ylab(ylab) +
         ggplot2::ggtitle(main) +
         ggplot2::coord_cartesian(xlim = c(xlim[1], xlim[2]), ylim = c(ylim[1], ylim[2])) +
-          {if(probability) ggplot2::geom_histogram(data = histdata, ggplot2::aes_(quote(values), quote(..density..)), breaks = reshist$breaks, boundary = 0, show.legend = FALSE, col = "black", alpha = 1, fill = datacol)
-            else ggplot2::geom_histogram(data = histdata, ggplot2::aes_(quote(values), quote(..count..)), breaks = reshist$breaks, boundary = 0, show.legend = FALSE, col = "black", alpha = 1, fill = datacol)} +
-        ggplot2::geom_line(data = fitteddens, ggplot2::aes_(linetype = quote(ind), colour = quote(ind)), size = 0.4) +
+        {if(probability) ggplot2::geom_histogram(data = histdata, ggplot2::aes(.data$values, ggplot2::after_stat(density)), breaks = reshist$breaks, boundary = 0, show.legend = FALSE, col = "black", alpha = 1, fill = datacol)
+          else ggplot2::geom_histogram(data = histdata, ggplot2::aes(.data$values, .data$..count..), breaks = reshist$breaks, boundary = 0, show.legend = FALSE, col = "black", alpha = 1, fill = datacol)} +
+        ggplot2::geom_line(data = fitteddens, ggplot2::aes(linetype = .data$ind, colour = .data$ind, size = .data$ind)) +
         ggplot2::guides(colour = ggplot2::guide_legend(title = NULL)) +
         ggplot2::guides(linetype = ggplot2::guide_legend(title = NULL)) +
+        ggplot2::guides(size = ggplot2::guide_legend(title = NULL)) +
         ggplot2::theme(plot.title = ggplot2::element_text(hjust = 0.5)) +
         {if(addlegend) ggplot2::theme(legend.position = c(xlegend, ylegend)) else ggplot2::theme(legend.position = "none")} +
         ggplot2::scale_color_manual(values = fitcol, labels = legendtext) +
-        ggplot2::scale_linetype_manual(values = fitlty, labels = legendtext)
+        ggplot2::scale_linetype_manual(values = fitlty, labels = legendtext) +
+        ggplot2::scale_size_manual(values = fitlwd, labels = legendtext)
       return(ggdenscomp)
       
     } else
@@ -315,19 +319,21 @@ denscomp <- function(ft, xlim, ylim, probability = TRUE, main, xlab, ylab,
                                                    sfin = as.numeric(names(table(mydata)))))
       
       ggdenscomp <-
-        ggplot2::ggplot(fitteddens, ggplot2::aes_(quote(sfin), quote(values), group = quote(ind), colour = quote(ind))) +
+        ggplot2::ggplot(fitteddens, ggplot2::aes(.data$sfin, .data$values, group = .data$ind, colour = .data$ind)) +
         ggplot2::xlab(xlab) +
         ggplot2::ylab(ylab) +
         ggplot2::ggtitle(main) +
         ggplot2::coord_cartesian(xlim = c(xlim[1], xlim[2]), ylim = c(ylim[1], ylim[2])) +
-        {if(fittype %in% c("l", "o")) ggplot2::geom_segment(data = fitteddens, ggplot2::aes_(x = quote(sfin), xend = quote(sfin), y = 0, yend = quote(values), linetype = quote(ind)))} +
-        {if(fittype %in% c("p", "o")) ggplot2::geom_point(data = fitteddens, ggplot2::aes_(x = quote(sfin), y = quote(values), colour = quote(ind)), shape = 1)} +
+        {if(fittype %in% c("l", "o")) ggplot2::geom_segment(data = fitteddens, ggplot2::aes(x = .data$sfin, xend = .data$sfin, y = 0, yend = .data$values, linetype = .data$ind, size = .data$ind))} +
+        {if(fittype %in% c("p", "o")) ggplot2::geom_point(data = fitteddens, ggplot2::aes(x = .data$sfin, y = .data$values, colour = .data$ind), shape = 1)} +
         ggplot2::guides(colour = ggplot2::guide_legend(title = NULL)) +
         ggplot2::guides(linetype = ggplot2::guide_legend(title = NULL)) +
+        ggplot2::guides(size = ggplot2::guide_legend(title = NULL)) +
         ggplot2::theme(plot.title = ggplot2::element_text(hjust = 0.5)) +
         {if(addlegend) ggplot2::theme(legend.position = c(xlegend, ylegend)) else ggplot2::theme(legend.position = "none")} +
         ggplot2::scale_color_manual(values = fitcol, labels = legendtext) +
-        ggplot2::scale_linetype_manual(values = fitlty, labels = legendtext)
+        ggplot2::scale_linetype_manual(values = fitlty, labels = legendtext) +
+        ggplot2::scale_size_manual(values = fitlwd, labels = legendtext)
       return(ggdenscomp)
       
     }
